==> dl.php?src=linea21_1_1.zip: linea21/languages/fr/lang_level.utf-8.php <==
<?php


// //////////////////////////////////////////////////
// Linea 21 - PHP language FR
// configuration des langues des modules
// create : 19/06/07
// last_modify : 20/06/07
// creative commons 2007 
//http://creativecommons.org/licenses/by-nc-sa/2.0/fr/legalcode
// //////////////////////////////////////////////////
/**
* lang_FR.php
* 
* @package linea21
* @author anthony 
* @copyright Copyright (c) green-box 2003
* @version 1.0
* @access public 
*/


/*	nommage des modules
*  	*/
$lang['level']['name']="niveau";
$lang['level']['confirm_mod'] = "Modification du niveau réalisé avec succès\n";


/*	nommage rubrique module
*  	*/
$lang['level']['mod']= "Modification d'un ".$lang['level']['name'];
$lang['level']['det']= "Détails du ".$lang['level']['name'];
$lang['level']['list']= "Consultation des ".$lang['level']['name']."x";


/*	nommage rubrique add / mod /det
*  	*/
$lang['level']['add_title']="Saisie des informations du nouveau ".$lang['level']['name'];
$lang['level']['mod_title']="Modification des informations du ".$lang['level']['name'];


/*	nommage élément rubrique
*  	*/
$lang['level']['denomination']="Nom ";
$lang['level']['description']="Description";
$lang['level']['comment']="Commentaire lié à ce ".$lang['level']['name'];
$lang['level']['visual_identity_new']= "Nouveau visuel";
$lang['level']['visual_identity']="Visuel lié à ce ".$lang['level']['name'];
$lang['level']['range']="Rang";




/*	nommage quickbox
*  	*/
$lang['level']['qb_title']=" dernières modifications effectuées";


/*	messages
*  	*/
$lang['level']['object_notdenomination']="Vous devez impérativement entrer une dénomination de niveau.";


/*	rubrique d'aide
*  	*/


$lang['level']['help_list1']="Pour afficher un niveau en détail, cliquez sur le nom de ce niveau";
$lang['level']['help_list2']="Vous pouvez modifier un niveau en cliquant sur l'icône de modification qui lui est associée";
$lang['level']['help_list3']="Vous pouvez faire une recherche de niveau à tout moment en cliquant sur 'recherche'";


$lang['level']['help_mod1']="Vous pouvez modifier chacun des paramètres dans le formulaire ci-dessus";
$lang['level']['help_mod2']="Après avoir validé le formulaire de modification, vérifiez les informations entrées dans le récapitulatif";
$lang['level']['help_mod3']="Si le récapitulaitf ne vous convient pas, vous pouvez cliquer sur 'revoir les paramètres' pour les modifier";

$lang['level']['help_det1']="Vous pouvez modifier ce niveau en cliquant sur l'icône de modification qui lui est associée";


?>

==> dl.php?src=linea21_1_6.zip: linea21/languages/fr/lang_level.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage fr
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


/*	nommage des modules
 *  	*/
$lang['level']['name']="niveau";
$lang['level']['confirm_mod'] = "Modification du niveau réalisé avec succès\n";


/*	nommage rubrique module
 *  	*/
$lang['level']['mod']= "Modification d'un ".$lang['level']['name'];
$lang['level']['det']= "Détails du ".$lang['level']['name'];
$lang['level']['list']= "Consultation des ".$lang['level']['name']."x";


/*	nommage rubrique add / mod /det
 *  	*/
$lang['level']['add_title']="Saisie des informations du nouveau ".$lang['level']['name'];
$lang['level']['mod_title']="Modification des informations du ".$lang['level']['name'];


/*	nommage élément rubrique
 *  	*/
$lang['level']['denomination']="Nom ";
$lang['level']['description']="Description";
$lang['level']['comment']="Commentaire lié à ce ".$lang['level']['name'];
$lang['level']['visual_identity_new']= "Nouveau visuel";
$lang['level']['visual_identity']="Visuel lié à ce ".$lang['level']['name'];
$lang['level']['range']="Rang";




/*	nommage quickbox
 *  	*/
$lang['level']['qb_title']=" dernières modifications effectuées";


/*	messages
 *  	*/
$lang['level']['object_notdenomination']="Vous devez impérativement entrer une dénomination de niveau.";


/*	rubrique d'aide
 *  	*/


$lang['level']['help_list1']="Pour afficher un niveau en détail, cliquez sur le nom de ce niveau";
$lang['level']['help_list2']="Vous pouvez modifier un niveau en cliquant sur l'icône de modification qui lui est associée";
$lang['level']['help_list3']="Vous pouvez faire une recherche de niveau à tout moment en cliquant sur 'recherche'";


$lang['level']['help_mod1']="Vous pouvez modifier chacun des paramètres dans le formulaire ci-dessus";
$lang['level']['help_mod2']="Après avoir validé le formulaire de modification, vérifiez les informations entrées dans le récapitulatif";
$lang['level']['help_mod3']="Si le récapitulaitf ne vous convient pas, vous pouvez cliquer sur 'revoir les paramètres' pour les modifier";

$lang['level']['help_det1']="Vous pouvez modifier ce niveau en cliquant sur l'icône de modification qui lui est associée";


?>
